@@ -58,6 +58,25 @@ class WorkbenchApplication(QApplication):
 		if self.args.gc_debug:
 			gc.set_debug(gc.DEBUG_STATS)
 
+		if not self.args.reset_config:
+			configs.loadFromFile()
+		else:
+			logging.warning("Resetting configuration!")
+		self._show_splash()
+
+		configs.registerOption(SettingsSection('View', 'View', 'Theme', 'Theme'),
+							   "AppTheme", "Theme", "select", {"options": [(x, x) for x in QStyleFactory.keys()]},
+							   "fusion", lambda key, value: self.setStyle(value))
+		load_file_watch(self, os.path.join(os.path.dirname(__file__), "stylesheet.css"),
+						lambda contents: self.setStyleSheet(contents))
+
+		from pre_workbench.project import Project
+		prj_dir = self._find_project()
+		if not prj_dir: sys.exit(1)
+		self.project = Project(prj_dir)
+		configs.updateMru("ProjectMru", prj_dir, 5)
+		configs.setValue("LastProjectDir", self.project.projectFolder)
+
 	def event(self, e):
 		"""Handle macOS FileOpen events."""
 		if e.type() == QEvent.FileOpen:
@@ -81,39 +100,43 @@ class WorkbenchApplication(QApplication):
 
 		return parser.parse_args(self.arguments()[1:])
 
+	def _find_project(self):
+		if not self.args.choose_project:
+			if self.args.project_dir and os.path.isdir(self.args.project_dir):
+				return sys.argv[1]
 
-def find_project(args):
-	if not args.choose_project:
-		if args.project_dir and os.path.isdir(args.project_dir):
-			return sys.argv[1]
+			last_prj = configs.getValue("LastProjectDir", None)
+			if last_prj and os.path.isfile(os.path.join(last_prj, ".pre_workbench")):
+				return last_prj
 
-		last_prj = configs.getValue("LastProjectDir", None)
-		if last_prj and os.path.isfile(os.path.join(last_prj, ".pre_workbench")):
-			return last_prj
+			if os.path.isfile(os.path.join(os.getcwd(), ".pre_workbench")):
+				return os.getcwd()
 
-		if os.path.isfile(os.path.join(os.getcwd(), ".pre_workbench")):
-			return os.getcwd()
+		if not self.args.choose_project:
+			QMessageBox.information(self.splash, "Welcome", "Welcome to PRE Workbench!\n\n"
+									"In the next dialog, you will be asked to choose a project directory. You can\n"
+									"- choose an existing project\n- create a new folder\n- select an existing folder\n\n"
+									"If it does not exist already, a project database file (named \".pre_workbench\") "
+									"will automatically be created in this directory.")
 
-	if not args.choose_project:
-		QMessageBox.information(None, "Welcome", "Welcome to PRE Workbench!\n\n"
-								"In the next dialog, you will be asked to choose a project directory. You can\n"
-								"- choose an existing project\n- create a new folder\n- select an existing folder\n\n"
-								"If it does not exist already, a project database file (named \".pre_workbench\") "
-								"will automatically be created in this directory.")
+		dlg = QFileDialog(self)
+		dlg.setFileMode(QFileDialog.DirectoryOnly)
+		dlg.setWindowTitle("Choose project directory")
+		if dlg.exec() == QFileDialog.Accepted:
+			return dlg.selectedFiles()[0]
 
-	dlg = QFileDialog()
-	dlg.setFileMode(QFileDialog.DirectoryOnly)
-	dlg.setWindowTitle("Choose project directory")
-	if dlg.exec() == QFileDialog.Accepted:
-		return dlg.selectedFiles()[0]
+		return None
+
+	def _show_splash(self):
+		splashimg = configs.respath("icons/splash.jpg")
+		self.splash = QSplashScreen(QPixmap(splashimg))
+		self.splash.showMessage("Version "+get_app_version(), QtCore.Qt.AlignBottom|QtCore.Qt.AlignLeft, QtCore.Qt.white)
+		self.splash.show()
 
-	return None
 
 
 def run_app():
 	global CurrentProject, MainWindow
-	from pre_workbench.project import Project
-	from pre_workbench.mainwindow import WorkbenchMain
 
 	errorhandler.initLogging()
 	logging.info("pre_workbench running on %s", " ".join(platform.uname()))
@@ -124,35 +147,12 @@ def run_app():
 	sys.excepthook = errorhandler.excepthook
 
 	app = WorkbenchApplication(sys.argv)
-	if not app.args.reset_config:
-		configs.loadFromFile()
-	else:
-		logging.warning("Resetting configuration!")
-	splash = show_splash()
+	CurrentProject = app.project
 
-	configs.registerOption(SettingsSection('View', 'View', 'Theme', 'Theme'),
-						   "AppTheme", "Theme", "select", {"options": [(x, x) for x in QStyleFactory.keys()]},
-						   "fusion", lambda key, value: app.setStyle(value))
-	load_file_watch(app, os.path.join(os.path.dirname(__file__), "stylesheet.css"), lambda contents: app.setStyleSheet(contents))
-
-	prj_dir = find_project(app.args)
-	if not prj_dir: sys.exit(1)
-	app_project = Project(prj_dir)
-	configs.updateMru("ProjectMru", prj_dir, 5)
-	CurrentProject = app_project
-	configs.setValue("LastProjectDir", app_project.projectFolder)
-
-	MainWindow = WorkbenchMain(app_project)
+	from pre_workbench.mainwindow import WorkbenchMain
+	MainWindow = WorkbenchMain(app.project)
 	MainWindow.show()
-	splash.finish(MainWindow)
+	app.splash.finish(MainWindow)
 	# os.system("/home/mw/test/Qt-Inspector/build/qtinspector "+str(os.getpid())+" &")
 	sys.exit(app.exec_())
 
-
-def show_splash():
-	splashimg = configs.respath("icons/splash.jpg")
-	splash = QSplashScreen(QPixmap(splashimg))
-	splash.showMessage("Version "+get_app_version(), QtCore.Qt.AlignBottom|QtCore.Qt.AlignLeft, QtCore.Qt.white)
-	splash.show()
-	return splash
-
