@@ -3,52 +3,23 @@ import time
 import traceback
 
 from PyQt5 import QtGui
-from PyQt5.QtCore import (Qt, pyqtSignal, QObject)
+from PyQt5.QtCore import (Qt)
 from PyQt5.QtGui import QColor
 from PyQt5.QtWidgets import QMenu, QFileDialog, QTreeWidget, QTreeWidgetItem, \
 	QTreeWidgetItemIterator, QMessageBox, QAction
 
-import pre_workbench.app
-from pre_workbench.configs import SettingsField
-from pre_workbench import configs, guihelper
-from pre_workbench.controls.genericwidgets import showSettingsDlg
+from pre_workbench import configs
 from pre_workbench.algo.range import Range
-
+from pre_workbench.configs import SettingsField
+from pre_workbench.controls.genericwidgets import showSettingsDlg
+from pre_workbench.controls.scintillaedit import showScintillaDialog
+from pre_workbench.interactive_fic import InteractiveFormatInfoContainer
 from pre_workbench.structinfo.format_info import FormatInfo, StructFI, VariantStructFI, SwitchFI, RepeatStructFI, \
 	UnionFI, BitStructFI
-from pre_workbench.structinfo.parsecontext import FormatInfoContainer
-from pre_workbench.structinfo.serialization import deserialize_fi
-from pre_workbench.controls.scintillaedit import showScintillaDialog
 from pre_workbench.typeeditor import showTypeEditorDlg, showTreeEditorDlg
 from pre_workbench.util import PerfTimer
 
 
-class InteractiveFormatInfoContainer(QObject, FormatInfoContainer):
-	updated = pyqtSignal()
-
-	def __init__(self, **kw):
-		QObject.__init__(self)
-		FormatInfoContainer.__init__(self, **kw)
-
-	def write_file(self, fileName):
-		super().write_file(fileName)
-		self.updated.emit()
-
-	def get_fi_by_def_name(self, def_name):
-		try:
-			return self.definitions[def_name]
-		except KeyError:
-			if QMessageBox.question(pre_workbench.app.MainWindow, "Format Info", "Reference to undefined formatinfo '" + def_name + "'. Create it now?") == QMessageBox.Yes:
-				params = showTypeEditorDlg("format_info.tes", "AnyFI", title="Create formatinfo '"+def_name+"'")
-				if params is None: raise
-				self.definitions[def_name] = deserialize_fi(params)
-				self.write_file(self.file_name)
-				return self.definitions[def_name]
-			else:
-				raise
-
-
-
 class RangeTreeWidget(QTreeWidget):
 	def __init__(self, parent=None):
 		super().__init__(parent)
