@@ -1,9 +1,10 @@
 
 class parse_exception(Exception):
-	def __init__(self, context, msg):
+	def __init__(self, context, msg, cause=None):
 		self.offset = context.offset()
 		self.context_hexdump = context.hexdump_context(self.offset)
 		super().__init__(context.get_path() + ": " + msg + "\n" + self.context_hexdump)
+		if cause: self.__cause__ = cause
 		self.parse_stack = context.stack
 
 
@@ -25,5 +26,5 @@ class value_not_found(parse_exception):
 class spec_error(parse_exception):
 	def __init__(self, context, msg):
 		super().__init__(context, "spec_error: "+msg)
-		self.offending_desc = context.stack[-1][0]
+		self.offending_desc = context.stack[-1].desc
 
